Skip site navigation (1)Skip section navigation (2)

  
 
  

home | help
oggz-comment(1) 	     General Commands Manual		 oggz-comment(1)

NAME
     oggz-comment -- List or edit comments in an Ogg file.

SYNOPSIS
     oggz-comment [-l  | --list ]

     oggz-comment [-o filename	| --output filename ]  [-d  | --delete ]  [-a  |
     --all  ]  [-s serialno  | --serialno serialno ]  [-c content-type	| --con-
     tent-type content-type ] filename

     oggz-comment [-h  | --help ]  [-v	| --version ]

Description
     oggz-comment lists or edits the comments of an Ogg file.

Options
     oggz-comment accepts the following options:

   Listing options
     -l, --listList the comments in the given file.

   Editing options
     -o filename, --output filename
	       Write output to the specified filename.

     -d, --delete
	       Delete comments before editing.

     -a, --all Edit comments for all logical bitstreams.

     -c content-type, --content-type content-type
	       Edit comments of the logical bitstreams with  specified	content-
	       type.   Run  oggz-known-codecs(1) for a full list of codecs known
	       by the installed version of oggz.

     -s serialno, --serialno serialno
	       Edit comments of the logical bitstream with specified serialno.

   Miscellaneous options
     -h, --helpDisplay usage information and exit.

     -v, --version
	       Output version information and exit.

EXAMPLES
     List all comments in file.ogg:

	    oggz comment -l file.ogg

     List only the comments in the Theora bitstream in file.ogv:

	    oggz comment -l -c theora file.ogv

     Add the comment "GENRE=Rock" to the Vorbis bitstream of  file.ogv,  writing
     output to output.ogv:

	    oggz comment -c vorbis -o output.ogv file.ogg GENRE=Rock

AUTHOR
     Kangyuan Niu	 August  5, 2007;

COPYRIGHT
     Copyright (C) 2007 Annodex Association

SEE ALSO
     vorbiscomment(1), ogginfo(1), oggz-info(1), hogg(1)

								 oggz-comment(1)

Want to link to this manual page? Use this URL:
<https://man.freebsd.org/cgi/man.cgi?query=oggz-comment&sektion=1&manpath=FreeBSD+Ports+15.1.quarterly>

home | help